diff -Nru cciss-vol-status-1.12/debian/cciss-vol-status.cciss-vol-statusd.init cciss-vol-status-1.12/debian/cciss-vol-status.cciss-vol-statusd.init
--- cciss-vol-status-1.12/debian/cciss-vol-status.cciss-vol-statusd.init	1970-01-01 01:00:00.000000000 +0100
+++ cciss-vol-status-1.12/debian/cciss-vol-status.cciss-vol-statusd.init	2019-07-03 13:12:46.000000000 +0200
@@ -0,0 +1,203 @@
+#! /bin/sh
+
+# Author: Petter Reinholdtsen <pere@hungry.com>
+# Author: Adam Cécile (Le_Vert) <gandalf@le-vert.net>
+# License: GNU General Public License v2 or later
+#
+### BEGIN INIT INFO
+# Provides:          cciss-vol-statusd
+# Description:       Check cciss_vol_status values in the background.
+# Required-Start:    $remote_fs $syslog
+# Required-Stop:     $remote_fs $syslog
+# Default-Start:     2 3 4 5
+# Default-Stop:      0 1 6
+# Short-Description: Check cciss_vol_status values in the background.
+### END INIT INFO
+
+PATH=/sbin:/bin:/usr/sbin:/usr/bin
+DESC="cciss-vol-status monitor"
+NAME=cciss-vol-statusd
+PIDFILE=/var/run/$NAME.pid
+STATUSFILE=/var/run/$NAME.status
+SCRIPTNAME=/etc/init.d/$NAME
+
+
+# Do not touch you can configure this in /etc/default/cciss-vol-statusd
+MAILTO=root   # Where to report problems
+PERIOD=600    # Seconds between each check    (default 10 minutes)
+REMIND=7200   # Seconds between each reminder (default 2 hours)
+RUN_DAEMON=yes
+ID=/dev/cciss/c0d0
+
+[ -e /etc/default/cciss-vol-statusd ] && . /etc/default/cciss-vol-statusd
+
+# Gracefully exit if the package has been removed.
+test -x /usr/sbin/cciss_vol_status || exit 0
+
+. /lib/lsb/init-functions
+[ -e /etc/default/rcS ] && . /etc/default/rcS
+
+if [ $RUN_DAEMON = "no" ] ; then
+	log_begin_msg "cciss-vol-statusd is disabled in /etc/default/cciss-vol-statusd, not starting."
+    	log_end_msg 0
+	exit 0
+fi
+
+check_cciss() {
+    echo $$ > $PIDFILE.new && mv $PIDFILE.new $PIDFILE
+    while true ; do
+        # Check ever $PERIOD seconds, send email on every status
+        # change and repeat ever $REMIND seconds if the raid is still
+        # bad.
+        if (cciss_vol_status $ID); then
+            BADRAID=false
+        else
+            BADRAID=true
+            logger -t cciss-vol-statusd "detected non-optimal RAID status"
+        fi
+        STATUSCHANGE=false
+        if [ true = "$BADRAID" ] ; then
+            # RAID not OK
+            (cciss_vol_status $ID) > $STATUSFILE.new
+            if [ ! -f $STATUSFILE ] ; then # RAID just became broken
+                STATUSCHANGE=true
+                mv $STATUSFILE.new $STATUSFILE
+            elif cmp -s $STATUSFILE $STATUSFILE.new ; then
+                # No change.  Should we send reminder?
+                LASTTIME="`stat -c '%Z' $STATUSFILE`"
+                NOW="`date +%s`"
+                SINCELAST="`expr $NOW - $LASTTIME`"
+                if [ $REMIND -le "$SINCELAST" ]; then
+                    # Time to send reminder
+                    STATUSCHANGE=true
+                    mv $STATUSFILE.new $STATUSFILE
+                else
+                    rm $STATUSFILE.new
+                fi
+            else
+                STATUSCHANGE=true
+                mv $STATUSFILE.new $STATUSFILE
+            fi
+        else
+            # RAID OK
+            if [ -f $STATUSFILE ] ; then
+                rm $STATUSFILE
+                STATUSCHANGE=true
+            fi
+        fi
+                
+        if [ true = "$STATUSCHANGE" ]; then
+            hostname="`uname -n`"
+            (
+                cat <<EOF 
+This is a RAID status update from cciss-vol-statusd.  The cciss_vol_status
+program reports that one of the RAIDs changed state:
+
+EOF
+                if [ -f $STATUSFILE ] ; then
+                    cat $STATUSFILE
+                else
+                    (cciss_vol_status $ID)
+                fi
+                echo
+                echo "Report from $0 on $hostname"
+            ) | mail -s "info: CCISS raid status change on $hostname" $MAILTO
+        fi
+	sleep $PERIOD &
+	# Kill sleep if we're signaled to exit, otherwise we will stay defunct
+	# until sleep terminates.
+	trap "kill $!; exit" TERM
+	wait $!
+	trap - TERM
+    done
+}
+
+check_daemon() {
+        # Let's check if there is a daemon which is really running and not timing out
+        DAEMON_RUN=`ps aux | grep "/etc/init.d/cciss-vol-statusd check_cciss" | grep -v grep | grep -v daemon`
+        if [ -n "$DAEMON_RUN" ] ; then
+                return 1;
+        else
+                return 0;
+        fi
+}
+
+#
+#       Function that starts the daemon/service.
+#
+d_start() {
+    [ -f $PIDFILE ] && PID="`cat $PIDFILE`"
+    if [ "$PID" ] ; then
+        log_progress_msg "Daemon already running. Refusing to start another"
+        return 0
+    elif check_daemon ; then
+        # Use the daemon package to turn this script into a daemon
+        start-stop-daemon --start --quiet --pidfile $PIDFILE \
+                --oknodo --exec /usr/bin/daemon /usr/bin/daemon $SCRIPTNAME check_cciss
+	return 0
+    else
+        log_progress_msg "Daemon is already running. Refusing to start another"
+        return 0
+    fi
+}
+
+#
+#       Function that stops the daemon/service.
+#
+d_stop() {
+        if [ -f $PIDFILE ] ; then
+             	start-stop-daemon --stop --oknodo --quiet --pidfile $PIDFILE > /dev/null 2>&1 
+		rm -f $PIDFILE
+        else
+                log_progress_msg "Daemon is already stopped."
+                return 0
+        fi
+}
+
+# This is a workaround function which does not directly exit and
+# therefore can be used by a restart
+d_stop_by_restart() {
+        if [ -f $PIDFILE ] ; then
+                start-stop-daemon --oknodo --stop --quiet --pidfile $PIDFILE
+                rm -f $PIDFILE
+                log_end_msg 0
+        else
+                log_progress_msg "Daemon is already stopped."
+                log_end_msg 0
+        fi
+}
+
+case "$1" in
+  start)
+        echo -n ""
+        log_begin_msg "Starting $DESC: $NAME"
+        d_start ; CODE=$?
+        log_end_msg $CODE
+        ;;
+  stop)
+        log_begin_msg "Stopping $DESC: $NAME"
+        d_stop ; CODE=$?
+        log_end_msg $CODE
+        ;;
+  check_cciss)
+        check_cciss
+        ;;
+  status)
+	status_of_proc /usr/bin/daemon $NAME
+	exit $?
+	;;
+  restart|force-reload)
+        log_begin_msg "Restarting $DESC: $NAME"
+        d_stop_by_restart
+        sleep 1
+        d_start || CODE=$?
+        log_end_msg $CODE
+        ;;
+  *)
+        # echo "Usage: $SCRIPTNAME {start|stop|restart|reload|force-reload}" >&2
+        echo "Usage: $SCRIPTNAME {start|stop|restart|force-reload}" >&2
+        exit 1
+        ;;
+esac
+
+exit 0
diff -Nru cciss-vol-status-1.12/debian/changelog cciss-vol-status-1.12/debian/changelog
--- cciss-vol-status-1.12/debian/changelog	2017-07-11 12:43:40.000000000 +0200
+++ cciss-vol-status-1.12/debian/changelog	2019-07-03 13:12:46.000000000 +0200
@@ -1,3 +1,15 @@
+cciss-vol-status (1.12-1+hwraid1) unstable; urgency=medium
+
+  * Use lsb-release to add unique distribution tag in pkgs version.
+  * Relax debhelper compat from 10 to 5 to support very old distributions.
+  * Rewrite rules to use regular legacy debhelper.
+  * Re-add dependency on bsd-mail | mailx.
+  * Switch source/format to 1.0 and introduce manual quilt for patch mgmt.
+  * Turn into a periodic service as cciss-vol-statusd based on work done
+    in mpt-status package.
+
+ -- Adam Cecile <acecile@le-vert.net>  Wed, 03 Jul 2019 12:44:51 +0200
+
 cciss-vol-status (1.12-1) unstable; urgency=medium
 
   * New upstream version 1.12
diff -Nru cciss-vol-status-1.12/debian/compat cciss-vol-status-1.12/debian/compat
--- cciss-vol-status-1.12/debian/compat	2017-07-11 12:43:40.000000000 +0200
+++ cciss-vol-status-1.12/debian/compat	2019-07-03 13:12:46.000000000 +0200
@@ -1 +1 @@
-10
+5
diff -Nru cciss-vol-status-1.12/debian/control cciss-vol-status-1.12/debian/control
--- cciss-vol-status-1.12/debian/control	2017-07-11 12:43:40.000000000 +0200
+++ cciss-vol-status-1.12/debian/control	2019-07-03 13:12:46.000000000 +0200
@@ -1,11 +1,13 @@
 Source: cciss-vol-status
 Section: admin
-Priority: extra
+Priority: optional
 Maintainer: Christian Hofstaedtler <zeha@debian.org>
 Build-Depends: autoconf,
                automake,
-               debhelper (>= 10),
-               dh-autoreconf
+               debhelper (>= 5),
+               autotools-dev,
+               quilt,
+               lsb-release,
 Build-Conflicts: autoconf2.13,
                  automake1.4
 Standards-Version: 4.0.0
@@ -16,7 +18,10 @@
 Package: cciss-vol-status
 Architecture: amd64 i386
 Depends: ${misc:Depends},
-         ${shlibs:Depends}
+         ${shlibs:Depends},
+         lsb-base,
+         daemon,
+         bsd-mailx | mailx,
 Description: HP SmartArray RAID Volume Status Checker
  A RAID monitor for HP SmartArray Controllers, as supported by the "cciss",
  "hpsa", "hpahcisr" kernel drivers.
diff -Nru cciss-vol-status-1.12/debian/docs cciss-vol-status-1.12/debian/docs
--- cciss-vol-status-1.12/debian/docs	2017-07-11 12:43:40.000000000 +0200
+++ cciss-vol-status-1.12/debian/docs	2019-07-03 13:12:46.000000000 +0200
@@ -1,2 +1,3 @@
 NEWS
 README
+debian/README.Debian
diff -Nru cciss-vol-status-1.12/debian/README.Debian cciss-vol-status-1.12/debian/README.Debian
--- cciss-vol-status-1.12/debian/README.Debian	1970-01-01 01:00:00.000000000 +0100
+++ cciss-vol-status-1.12/debian/README.Debian	2019-07-03 13:12:46.000000000 +0200
@@ -0,0 +1,27 @@
+README.Debian for cciss-vol-status package
+------------------------------------------
+
+Possible configuration:
+----------------------
+
+If you want to change the default configuration of the init script you
+can create the file /etc/default/cciss-vol-statusd and specify the following
+values.
+
+MAILTO=
+PERIOD=
+REMIND=
+ID=
+
+Use MAILTO to specify which user shall get the status mails 
+(default is root).
+
+With PERIOD you can fix the seconds between each check.
+
+And REMIND specifies the seconds between each reminder.
+
+ID is set as default to /dev/cciss/c0d0 which should fit most of setups.
+However you need to change it to support multiple cards.
+Look at the cciss-vol-status(8) manpage for more information.
+
+ -- Adam Cécile (Le_Vert) <gandalf@le-vert.net>  Wed, 20 Aug 2008 12:38:00 +0200
diff -Nru cciss-vol-status-1.12/debian/rules cciss-vol-status-1.12/debian/rules
--- cciss-vol-status-1.12/debian/rules	2017-07-11 12:43:40.000000000 +0200
+++ cciss-vol-status-1.12/debian/rules	2019-07-03 13:12:46.000000000 +0200
@@ -1,12 +1,94 @@
 #!/usr/bin/make -f
-# -*- makefile -*-
 
+# Quilt patch system
+include /usr/share/quilt/quilt.make
+
+# Uncomment this to turn on verbose mode.
+#export DH_VERBOSE=1
+
+# These are used for cross-compiling and for saving the configure script
+# from having to guess our platform (since we know it already)
+DEB_HOST_GNU_TYPE   ?= $(shell dpkg-architecture -qDEB_HOST_GNU_TYPE)
+DEB_BUILD_GNU_TYPE  ?= $(shell dpkg-architecture -qDEB_BUILD_GNU_TYPE)
+ifneq ($(DEB_HOST_GNU_TYPE),$(DEB_BUILD_GNU_TYPE))
+CROSS= --build $(DEB_BUILD_GNU_TYPE) --host $(DEB_HOST_GNU_TYPE)
+else
+CROSS= --build $(DEB_BUILD_GNU_TYPE)
+endif
+
+DESTDIR=$(CURDIR)/debian/cciss-vol-status
+
+CFLAGS := $(shell dpkg-buildflags --get CFLAGS)
+LDFLAGS := $(shell dpkg-buildflags --get LDFLAGS)
 export DEB_BUILD_MAINT_OPTIONS = hardening=+all
-DPKG_EXPORT_BUILDFLAGS = 1
-include /usr/share/dpkg/buildflags.mk
 
-%:
-	dh $@ --with autoreconf
+# Get version from changelog as well as lsb_release
+# to compute unique build version (useful for repo mirroring systems doing file pooling)
+PKG_VERSION  := $(shell dpkg-parsechangelog | egrep '^Version:' | cut -f2 -d' ')
+DIST_NAME    := $(shell lsb_release -si)
+DIST_RELEASE := $(shell lsb_release -sc)
+DIST_VERSION := $(shell lsb_release -sr)
+PKG_VERSION_TAG := $(PKG_VERSION)+$(DIST_NAME).$(DIST_RELEASE).$(DIST_VERSION)
+SUBSTVARS_BINARY_VERSION := -Vbinary:Version="$(PKG_VERSION_TAG)"
+SUBSTVARS_SOURCE_VERSION := -Vsource:Version="$(PKG_VERSION_TAG)"
+
+configure: patch
 
-override_dh_installdocs:
+config.status: configure
+	dh_testdir
+ifneq "$(wildcard /usr/share/misc/config.sub)" ""
+	cp -f /usr/share/misc/config.sub config.sub
+endif
+ifneq "$(wildcard /usr/share/misc/config.guess)" ""
+	cp -f /usr/share/misc/config.guess config.guess
+endif
+	./configure $(CROSS) \
+		    --prefix=/usr \
+		    --bindir=/usr/sbin \
+		    --mandir=/usr/share/man \
+		    CFLAGS="$(CFLAGS)" \
+		    LDFLAGS="$(LDFLAGS)"
+
+build: build-arch build-indep
+build-indep:
+build-arch: config.status 
+	dh_testdir
+	$(MAKE)
+	touch $@
+
+clean: unpatch
+	dh_testdir
+	dh_testroot
+	rm -f build-arch 
+	[ ! -f Makefile ] || $(MAKE) distclean
+	rm -f config.sub config.guess config.log
+	dh_clean 
+
+install: build
+	dh_testdir
+	dh_testroot
+	dh_clean -k 
+	dh_installdirs
+	$(MAKE) DESTDIR=$(DESTDIR) install
+
+binary-indep: build install
+binary-arch: build install
+	dh_testdir
+	dh_testroot
+	dh_installchangelogs ChangeLog
 	dh_installdocs -XREADME
+	dh_installexamples
+	dh_installman
+	dh_installinit --name=cciss-vol-statusd
+	dh_link
+	dh_strip
+	dh_compress
+	dh_fixperms
+	dh_installdeb
+	dh_shlibdeps
+	dh_gencontrol -- -v"$(PKG_VERSION_TAG)" $(SUBSTVARS_BINARY_VERSION) $(SUBSTVARS_SOURCE_VERSION)
+	dh_md5sums
+	dh_builddeb
+
+binary: binary-indep binary-arch
+.PHONY: build clean binary-indep binary-arch binary install 
diff -Nru cciss-vol-status-1.12/debian/source/format cciss-vol-status-1.12/debian/source/format
--- cciss-vol-status-1.12/debian/source/format	2017-07-11 12:43:40.000000000 +0200
+++ cciss-vol-status-1.12/debian/source/format	2019-07-03 13:12:46.000000000 +0200
@@ -1 +1 @@
-3.0 (quilt)
+1.0
